@@ -13,17 +13,47 @@ import pathlib
 import re
 import subprocess
 from paver.easy import sh
-from pkg_resources import resource_string, resource_filename, require
-from .pretext.chapter_pop import manifest_data_to_db
+import importlib.metadata
+import importlib.resources
 import codecs
 from runestone.server import get_dburl
-from runestone.server.utils import update_library
+from rsptx.build_tools.core import update_library, populate_static, manifest_data_to_db
+from rsptx.cl_utils.core import load_project_dotenv
+
+
+def lets_exit(code=0):
+    click.echo(
+        click.style(
+            "The runestone command is deprecated.  You should convert your book to PreTeXt.",
+            fg="yellow",
+            bold=True,
+        ),
+        color=True,
+    )
+    sys.exit(code)
+
+
+def deprecation_warning():
+    click.echo(
+        click.style(
+            """The runestone command and RST extensions are deprecated.
+You should convert your book to PreTeXt.
+We will continue to add features to the interactive components, but
+you will only have access to them through PreTeXt.""",
+            fg="yellow",
+            bold=True,
+        ),
+        color=True,
+    )
+
 
 if len(sys.argv) == 2:
     if "--version" in sys.argv:
-        version = require("runestone")[0].version
+        version = importlib.metadata.version("runestone")
         print("Runestone version {}".format(version))
-        sys.exit()
+        lets_exit()
+
+load_project_dotenv()
 
 
 @click.group(chain=True)
@@ -34,16 +64,22 @@ def cli(version):
 
     """
     if version:
-        version = require("runestone")[0].version
+        version = importlib.metadata.version("runestone")
         print("Runestone version {}".format(version))
-        sys.exit()
+        lets_exit()
 
 
 @cli.command()
 def init():
-    template_base_dir = resource_filename("runestone", "common/project_template")
-    config_stuff = resource_string("runestone", "common/project_template/conf.tmpl")
-    paver_stuff = resource_string("runestone", "common/project_template/pavement.tmpl")
+    template_base_dir = pathlib.Path(
+        importlib.resources.files("runestone.common").joinpath("project_template")
+    ).absolute()
+    config_stuff = importlib.resources.read_text(
+        "runestone.common.project_template", "conf.tmpl"
+    )
+    paver_stuff = importlib.resources.read_text(
+        "runestone.common.project_template", "pavement.tmpl"
+    )
     conf_dict = {}
     print("This will create a new Runestone project in your current directory.")
     click.confirm("Do you want to proceed? ", abort=True, default=True)
@@ -70,9 +106,9 @@ def init():
         "Default ActiveCode language", default="python"
     )
     if conf_dict["use_services"] == "true":
-        conf_dict[
-            "project_name"
-        ] = "os.path.basename(os.path.dirname(os.path.abspath(__file__)))"
+        conf_dict["project_name"] = (
+            "os.path.basename(os.path.dirname(os.path.abspath(__file__)))"
+        )
         conf_dict["build_dir"] = "./build"
         conf_dict["dest"] = "./published"
         conf_dict["login_req"] = click.prompt("Require login ", default="false")
@@ -155,23 +191,46 @@ def build(all, wd):
     else:
         os.chdir(findProjectRoot())
     sys.path.insert(0, os.getcwd())
-    if not pathlib.Path(
-        resource_filename("runestone", "dist/webpack_static_imports.json")
-    ).exists():
+    try:
+        with importlib.resources.path(
+            "runestone.dist", "webpack_static_imports.json"
+        ) as p:
+            if not pathlib.Path(p).exists():
+                click.echo(
+                    "Error -- you are missing webpack_static_imports.json.  Please make sure"
+                )
+                click.echo(
+                    "you have run projects/interactives/build.py to generate this file"
+                )
+                lets_exit(-1)
+    except ModuleNotFoundError:
         click.echo(
             "Error -- you are missing webpack_static_imports.json.  Please make sure"
         )
-        click.echo("you have Runestone installed correctly.")
-        click.echo("In a development environment, execute npm run build.")
-        sys.exit(-1)
+        click.echo("you have runestone and the node dependencies installed correctly.")
+        click.echo(
+            "In a development environment, execute npm run build in bases/rsptx/interactives"
+        )
+        lets_exit(-1)
 
-    version = require("runestone")[0].version
+    version = importlib.metadata.version("runestone")
     print("Building with Runestone {}".format(version))
 
     import pavement
 
     confpath = pathlib.Path(pavement.options.get("confdir", "."))
 
+    if pavement.options.build.template_args["basecourse"] != pavement.project_name:
+        click.echo(
+            click.style(
+                f"""Please update pavement.py so that basecourse ({pavement.options.build.template_args["basecourse"]})
+                            and project_name ({pavement.project_name}) match""",
+                fg="red",
+            ),
+            err=True,
+            color=True,
+        )
+        lets_exit(1)
     with open(confpath / "conf.py", encoding="utf-8") as cf:
         ctext = cf.read()
         if not re.search(r"from runestone import.*(setup|script_files)", ctext):
@@ -190,7 +249,7 @@ def build(all, wd):
             click.echo(
                 "Change it to:\nfrom runestone import runestone_static_dirs, runestone_extensions, setup"
             )
-            sys.exit(1)
+            lets_exit(1)
 
     if not os.path.exists(pavement.options.build.builddir):
         os.makedirs(pavement.options.build.builddir)
@@ -212,6 +271,8 @@ def build(all, wd):
             course = pavement.options.template_args["course_id"]
         update_library(config, "", course, click, build_system="Runestone")
 
+    deprecation_warning()
+
 
 @cli.command(short_help="preview the book in a minimal server (NO API support)")
 @click.option("--port", default=8000, help="port for server to listen on")
@@ -340,13 +401,14 @@ def rs2ptx(course, sourcedir, outdir):
     """
     os.chdir(findProjectRoot())
     sys.path.insert(0, os.getcwd())
-    del os.environ["DBURL"]
+    if "DBURL" in os.environ:
+        del os.environ["DBURL"]
     try:
         import pavement
     except Exception as e:
         click.echo("Could not read pavement.py file, aborting")
         click.echo(f"Details: {e}")
-        sys.exit(1)
+        lets_exit(1)
 
     if not course:
         if pavement.project_name:
@@ -413,7 +475,9 @@ def update():
     you can merge your changes (in _templates.bak) after you run this command.
     """
     os.chdir(findProjectRoot())
-    template_base_dir = resource_filename("runestone", "common/project_template")
+    template_base_dir = pathlib.Path(
+        importlib.resources.files("runestone.common").joinpath("project_template")
+    ).absolute()
     print("This will update all files in the _templates folder.")
     print(
         "The old _templates folder will be in _templates.bak so you can merge manually after you update"
@@ -447,13 +511,24 @@ def process_manifest(course, manifest):
         raise IOError("You must provide a valid path to a manifest file")
 
 
+@cli.command(short_help="Fetch Javascript/CSS from CDN and copy to _static")
+@click.option("--course", help="Name of the course (base course)")
+def fetch_latest_static(course):
+    config = type("config", (object,), {})()
+    config.dburl = get_dburl()
+    os.chdir(findProjectRoot())
+    manifest = "runestone-manifest.xml"
+    mpath = pathlib.Path(os.getcwd(), "published", course, manifest)
+    populate_static(config, mpath, course)
+
+
 def main(args=None):
     sys.dont_write_bytecode = True
     if not args:
         args = sys.argv[1:]
     if not args:
         print("""Usage: runestone help for a list of commands""")
-        sys.exit(0)
+        lets_exit(0)
     cli.add_command(init)
     cli.add_command(build)
     cli.add_command(serve)
@@ -469,10 +544,12 @@ def findProjectRoot():
     while start != prevdir:
         if os.path.exists(os.path.join(start, "pavement.py")):
             return start
+        if os.path.exists(os.path.join(start, "project.ptx")):
+            return start
         prevdir = start
         start = os.path.dirname(start)
     raise IOError("You must be in a runestone project to run runestone")
 
 
 if __name__ == "__main__":
-    sys.exit(main(sys.argv[1:]))
+    lets_exit(main(sys.argv[1:]))
