@@ -53,8 +53,11 @@ def setup(app):
     app.add_config_value("activecode_hide_load_history", False, "html")
     app.add_config_value("wasm_uri", "/_static", "html")
 
-    app.add_node(ActivecodeNode, html=(visit_ac_html, depart_ac_html),
-                 xml=(visit_ac_xml, depart_ac_xml))
+    app.add_node(
+        ActivecodeNode,
+        html=(visit_ac_html, depart_ac_html),
+        xml=(visit_ac_xml, depart_ac_xml),
+    )
 
     app.connect("doctree-resolved", process_activcode_nodes)
     app.connect("env-purge-doc", purge_activecodes)
@@ -68,18 +71,22 @@ XML_EX_START = """
 XML_EX_END = """
     </statement>
     <program xml:id="{divid}_editor" interactive='activecode' language="{language}">
+{optional_prefix_code}
         <input>
-{initialcode}
+{xml_source_code}
         </input>
+{optional_suffix_code}
     </program>
 </exercise>
 """
 
 XML_LISTING_START = """
     <program xml:id="{divid}" interactive='activecode' language="{language}">
+{optional_prefix_code}
         <input>
-{initialcode}
+{xml_source_code}
         </input>
+{optional_suffix_code}
     </program>
 """
 
@@ -87,7 +94,7 @@ XML_LISTING_START = """
 TEMPLATE_START = """
 <div class="%(divclass)s %(optclass)s">
 <div data-component="activecode" id=%(divid)s data-question_label="%(question_label)s">
-<div id=%(divid)s_question class="ac_question col-md-12">
+<div id=%(divid)s_question class="ac_question">
 """
 
 TEMPLATE_END = """
@@ -109,15 +116,37 @@ class ActivecodeNode(nodes.General, nodes.Element, RunestoneIdNode):
 
 
 def visit_ac_xml(self, node):
+    node["runestone_options"]["xml_source_code"] = (
+        node["runestone_options"]["xml_source_code"]
+        .replace("<", "&lt;")
+        .replace(">", "&gt;")
+    )
     if node["runestone_options"]["has_problem_statement"]:
         res = XML_EX_START.format(**node["runestone_options"])
         self.output.append(res)
-    else:
-        node["runestone_options"]["initialcode"] = node["runestone_options"]["initialcode"].replace(
-            "<", "&lt;").replace(">", "&gt;")
 
 
 def depart_ac_xml(self, node):
+    if node["runestone_options"]["xml_prefix_code"]:
+        node["runestone_options"]["optional_prefix_code"] = (
+            "<prefix>\n"
+            + node["runestone_options"]["xml_prefix_code"]
+            .replace("<", "&lt;")
+            .replace(">", "&gt;")
+            + "\n</prefix>\n"
+        )
+    else:
+        node["runestone_options"]["optional_prefix_code"] = ""
+    if node["runestone_options"]["xml_suffix_code"]:
+        node["runestone_options"]["optional_suffix_code"] = (
+            "<tests>\n"
+            + node["runestone_options"]["xml_suffix_code"]
+            .replace("<", "&lt;")
+            .replace(">", "&gt;")
+            + "\n</tests>\n"
+        )
+    else:
+        node["runestone_options"]["optional_suffix_code"] = ""
     if node["runestone_options"]["has_problem_statement"]:
         res = XML_EX_END.format(**node["runestone_options"])
         self.output.append(res)
@@ -125,6 +154,7 @@ def depart_ac_xml(self, node):
         res = XML_LISTING_START.format(**node["runestone_options"])
         self.output.append(res)
 
+
 # self for these functions is an instance of the writer class.  For example
 # in html, self is sphinx.writers.html.SmartyPantsHTMLTranslator
 # The node that is passed as a parameter is an instance of our node class.
@@ -280,6 +310,9 @@ class ActiveCode(RunestoneIdDirective):
             self.options["has_problem_statement"] = False
             self.explain_text = ["Not an Exercise"]
 
+        if self.content and "unittest.gui" in source:
+            self.options["autograde"] = "unittest"
+
         addQuestionToDB(self)
 
         self.options["initialcode"] = source
@@ -435,6 +468,8 @@ class ActiveCode(RunestoneIdDirective):
             if "^^^^" in self.content:
                 idx = self.content.index("^^^^")
                 prefix = "\n".join(self.content[:idx])
+            else:
+                prefix = ""
             if "====" in self.content:
                 idx = self.content.index("====")
                 source = "\n".join(self.content[:idx])
@@ -445,6 +480,11 @@ class ActiveCode(RunestoneIdDirective):
         else:
             source = "\n"
             suffix = "\n"
+            prefix = "\n"
+
+        self.options["xml_prefix_code"] = prefix
+        self.options["xml_source_code"] = source
+        self.options["xml_suffix_code"] = suffix
 
         course_name = env.config.html_context["course_id"]
         divid = self.options["divid"]
@@ -453,14 +493,14 @@ class ActiveCode(RunestoneIdDirective):
 
         if engine:
             Source_code = Table(
-                "source_code", meta, autoload=True, autoload_with=engine
+                "source_code", meta, autoload_with=engine
             )
-            engine.execute(
+            sess.execute(
                 Source_code.delete()
                 .where(Source_code.c.acid == divid)
                 .where(Source_code.c.course_id == course_name)
             )
-            engine.execute(
+            sess.execute(
                 Source_code.insert().values(
                     acid=divid,
                     course_id=course_name,
@@ -489,7 +529,8 @@ class ActiveCode(RunestoneIdDirective):
         acnode = ActivecodeNode()
         acnode["runestone_options"] = self.options
         acnode["source"], acnode["line"] = self.state_machine.get_source_and_line(
-            self.lineno)
+            self.lineno
+        )
         self.add_name(acnode)  # make this divid available as a target for :ref:
 
         maybeAddToAssignment(self)
