@@ -30,7 +30,10 @@ from runestone.server.componentdb import (
     getQuestionID,
     get_HTML_from_DB,
 )
-from runestone.common.runestonedirective import RunestoneDirective, RunestoneNode
+from runestone.common.runestonedirective import (
+    RunestoneDirective,
+    RunestoneNode,
+)
 from datetime import datetime
 
 
@@ -84,12 +87,12 @@ def purge(app, env, docname):
 
 class Assignment(RunestoneDirective):
     """
-        .. assignment:
-            :name: Problem Set 1
-            :assignment_type: formative
-            :questions: (divid_1 50), (divid_2 100), ...
-            :deadline: 23-09-2016 15:30
-            :points: integer
+    .. assignment:
+        :name: Problem Set 1
+        :assignment_type: formative
+        :questions: (divid_1 50), (divid_2 100), ...
+        :deadline: 23-09-2016 15:30
+        :points: integer
     """
 
     required_arguments = 0  # not a sphinx_id for these; just a name parameter
@@ -111,15 +114,15 @@ class Assignment(RunestoneDirective):
 
     def run(self):
         """
-            .. assignment:
-                :name: Problem Set 1
-                :assignment_type: formative
-                :questions: (divid_1 50), (divid_2 100), ...
-                :deadline: 23-09-2016 15:30
-                :points: integer
-                :threshold: integer
-                :autograde: visited
-                :generate_html:
+        .. assignment:
+            :name: Problem Set 1
+            :assignment_type: formative
+            :questions: (divid_1 50), (divid_2 100), ...
+            :deadline: 23-09-2016 15:30
+            :points: integer
+            :threshold: integer
+            :autograde: visited
+            :generate_html:
         """
 
         course_name = self.state.document.settings.env.config.html_context["course_id"]
@@ -154,9 +157,10 @@ class Assignment(RunestoneDirective):
 
         if "generate_html" in self.options:
             assignment_node = AssignmentNode(self.options, rawsource=self.block_text)
-            assignment_node.source, assignment_node.line = self.state_machine.get_source_and_line(
-                self.lineno
-            )
+            (
+                assignment_node.source,
+                assignment_node.line,
+            ) = self.state_machine.get_source_and_line(self.lineno)
             return [assignment_node]
         else:
             return []
