@@ -17,7 +17,10 @@ __author__ = "isaacdontjelindell"
 
 from docutils import nodes
 from docutils.parsers.rst import directives
-from runestone.common.runestonedirective import RunestoneDirective, RunestoneNode
+from runestone.common.runestonedirective import (
+    RunestoneDirective,
+    RunestoneNode,
+)
 
 
 DISQUS_BOX = """\
@@ -100,9 +103,9 @@ def purge_disqus_nodes(app, env, docname):
 
 class DisqusDirective(RunestoneDirective):
     """
-.. disqus::
-   :shortname: Your registered disqus id
-   :identifier: unique id for this discussion
+    .. disqus::
+       :shortname: Your registered disqus id
+       :identifier: unique id for this discussion
     """
 
     required_arguments = 0
@@ -126,7 +129,8 @@ class DisqusDirective(RunestoneDirective):
 
         disqus_node = DisqusNode()
         disqus_node["runestone_options"] = self.options
-        disqus_node["source"], disqus_node["line"] = self.state_machine.get_source_and_line(
-            self.lineno
-        )
+        (
+            disqus_node["source"],
+            disqus_node["line"],
+        ) = self.state_machine.get_source_and_line(self.lineno)
         return [disqus_node]
