@@ -33,15 +33,18 @@ from runestone.common.xmlcommon import write_substitute
 def setup(app):
     app.add_directive("dragndrop", DragNDrop)
 
-    app.add_node(DragNDropNode, html=(visit_dnd_html, depart_dnd_html),
-                 xml=(visit_dnd_xml, depart_dnd_xml))
+    app.add_node(
+        DragNDropNode,
+        html=(visit_dnd_html, depart_dnd_html),
+        xml=(visit_dnd_xml, depart_dnd_xml),
+    )
 
     app.add_config_value("dragndrop_div_class", "runestone", "html")
 
 
 TEMPLATE_START = """
 <div class="%(divclass)s  %(optclass)s">
-<ul data-component="dragndrop" data-question_label="%(question_label)s" id="%(divid)s" %(optional)s style="visibility: hidden;">
+<ul data-component="dragndrop" data-question_label="%(question_label)s" id="%(divid)s" %(randomize)s %(optional)s style="visibility: hidden;">
     <span data-subcomponent="question">%(qnumber)s: %(question)s</span>
 	%(feedback)s
 """
@@ -62,6 +65,7 @@ XML_START = """
 class DragNDropNode(nodes.General, nodes.Element, RunestoneIdNode):
     pass
 
+
 # self for these functions is an instance of the writer class.  For example
 # in html, self is sphinx.writers.html.SmartyPantsHTMLTranslator
 # The node that is passed as a parameter is an instance of our node class.
@@ -72,9 +76,7 @@ def visit_dnd_xml(self, node):
 
     if "feedback" in node["runestone_options"]:
         node["runestone_options"]["feedback"] = (
-            "<feedback><p>"
-            + node["runestone_options"]["feedback"]
-            + "</p></feedback>"
+            "<feedback><p>" + node["runestone_options"]["feedback"] + "</p></feedback>"
         )
     else:
         node["runestone_options"]["feedback"] = ""
@@ -133,6 +135,13 @@ def visit_dnd_common(self, node):
     else:
         node["runestone_options"]["feedback"] = ""
 
+    # Add runestone_options : random : data-random to node
+    if "randomize" in node["runestone_options"]:
+        node["runestone_options"]["randomize"] = "data-random"
+    else:
+        node["runestone_options"]["randomize"] = ""
+    
+
     res = res % node["runestone_options"]
     return res
 
@@ -157,22 +166,22 @@ def depart_dnd_common(self, node):
 
 class DragNDrop(RunestoneIdDirective):
     """
-.. dragndrop:: identifier
-    :feedback: Feedback that is displayed if things are incorrectly matched--is optional
-    :match_1: Draggable element text|||Dropzone to be matched with text
-    :match_2: Drag to Answer B|||Answer B
-    :match_3: Draggable text|||Text of dropzone
-    etc. (up to 20 matches)
+    .. dragndrop:: identifier
+        :feedback: Feedback that is displayed if things are incorrectly matched--is optional
+        :match_1: Draggable element text|||Dropzone to be matched with text
+        :match_2: Drag to Answer B|||Answer B
+        :match_3: Draggable text|||Text of dropzone
+        etc. (up to 20 matches)
 
-    The question goes here.
+        The question goes here.
 
-config values (conf.py):
+    config values (conf.py):
 
-- dragndrop_div_class - custom CSS class of the component's outermost div
+    - dragndrop_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1
-    optional_arguments = 0
+    optional_arguments = 1
     has_content = True
     option_spec = RunestoneIdDirective.option_spec.copy()
     option_spec.update(
@@ -198,22 +207,23 @@ config values (conf.py):
             "match_18": directives.unchanged,
             "match_19": directives.unchanged,
             "match_20": directives.unchanged,
+            "randomize": directives.flag,
         }
     )
 
     def run(self):
         """
-            process the multiplechoice directive and generate html for output.
-            :param self:
-            :return:
-            .. dragndrop:: identifier
-                :feedback: Feedback that is displayed if things are incorrectly matched--is optional
-                :match_1: Draggable element text|||Dropzone to be matched with text
-                :match_2: Drag to Answer B|||Answer B
-                :match_3: Draggable text|||Text of dropzone
-                ...etc...(up to 20 matches)
+        process the multiplechoice directive and generate html for output.
+        :param self:
+        :return:
+        .. dragndrop:: identifier
+            :feedback: Feedback that is displayed if things are incorrectly matched--is optional
+            :match_1: Draggable element text|||Dropzone to be matched with text
+            :match_2: Drag to Answer B|||Answer B
+            :match_3: Draggable text|||Text of dropzone
+            ...etc...(up to 20 matches)
 
-                The question goes here.
+            The question goes here.
         """
         super(DragNDrop, self).run()
         addQuestionToDB(self)
