@@ -31,6 +31,7 @@ from runestone.common.runestonedirective import (
     RunestoneIdNode,
 )
 
+
 def setup(app):
     app.add_directive("hparsons", HParsonsDirective)
     app.add_node(HParsonsNode, html=(visit_hp_html, depart_hp_html))
@@ -39,7 +40,7 @@ def setup(app):
 TEMPLATE_START = """
 <div class="runestone">
 <div data-component="hparsons" id=%(divid)s data-question_label="%(question_label)s" class="alert alert-warning hparsons_section">
-<div class="hp_question col-md-12">
+<div class="hp_question">
 """
 
 TEMPLATE_END = """
@@ -102,10 +103,16 @@ class HParsonsDirective(RunestoneIdDirective):
         Here is the problem description. It must ends with the tildes.
         Make sure you use the correct delimitier for each section below.
         ~~~~
+        --hiddenprefix--
+        // code that is for scaffolding the execution (e.g. initializing database)
         --blocks--
         block 1
         block 2
         block 3
+        --hiddensuffix--
+        // code that is for scaffolding unittest/execution (e.g. adding query for database)
+        // most of the time the hiddensuffix is just "select * from table" to
+        //      get all entries from the table to test the update or other operations.
         --unittest--
         assert 1,1 == world
         assert 0,1 == hello
@@ -133,24 +140,28 @@ class HParsonsDirective(RunestoneIdDirective):
         env = self.state.document.settings.env
 
         if "language" in self.options:
-            self.options["language"] = "data-language='{}'".format(self.options["language"])
+            self.options["language"] = "data-language='{}'".format(
+                self.options["language"]
+            )
         else:
             self.options["language"] = ""
 
         if "reuse" in self.options:
-            self.options['reuse'] = ' data-reuse="true"'
+            self.options["reuse"] = ' data-reuse="true"'
         else:
-            self.options['reuse'] = ''
+            self.options["reuse"] = ""
 
         if "randomize" in self.options:
-            self.options['randomize'] = ' data-randomize="true"'
+            self.options["randomize"] = ' data-randomize="true"'
         else:
-            self.options['randomize'] = ''
+            self.options["randomize"] = ""
 
         if "blockanswer" in self.options:
-            self.options["blockanswer"] = "data-blockanswer='{}'".format(self.options["blockanswer"])
+            self.options["blockanswer"] = "data-blockanswer='{}'".format(
+                self.options["blockanswer"]
+            )
         else:
-            self.options['blockanswer'] = ''
+            self.options["blockanswer"] = ""
 
         explain_text = None
         if self.content:
@@ -177,7 +188,9 @@ class HParsonsDirective(RunestoneIdDirective):
 
         hpnode = HParsonsNode()
         hpnode["runestone_options"] = self.options
-        hpnode["source"], hpnode["line"] = self.state_machine.get_source_and_line(self.lineno)
+        hpnode["source"], hpnode["line"] = self.state_machine.get_source_and_line(
+            self.lineno
+        )
         self.add_name(hpnode)  # make this divid available as a target for :ref:
 
         maybeAddToAssignment(self)
