@@ -17,7 +17,10 @@ from __future__ import print_function
 
 from docutils import nodes
 from docutils.parsers.rst import directives
-from runestone.common.runestonedirective import RunestoneDirective, RunestoneNode
+from runestone.common.runestonedirective import (
+    RunestoneDirective,
+    RunestoneNode,
+)
 import re
 
 __author__ = "Wayne Brown"
@@ -60,38 +63,38 @@ def setup(app):
 # This initializes the new directive
 class MatrixEq(RunestoneDirective):
     """
-.. matrixeq:: uniqueid
-    :notexecutable: -- the matrix equation can't be executed by the user
-    :comment: -- A comment to include to the right of the equation
-    :nolabel: -- don't label the equation using the uniqueid provided
-    :backgroundcolor: -- the color of the background; either #RRBBGG or a color name
-    :foregroundcolor: -- the color used for the matrix elements; either #RRBBGG or a color name
-    :highlightcolor: -- the color used for "bolded" elements; ; either #RRBBGG or a color name
+    .. matrixeq:: uniqueid
+        :notexecutable: -- the matrix equation can't be executed by the user
+        :comment: -- A comment to include to the right of the equation
+        :nolabel: -- don't label the equation using the uniqueid provided
+        :backgroundcolor: -- the color of the background; either #RRBBGG or a color name
+        :foregroundcolor: -- the color used for the matrix elements; either #RRBBGG or a color name
+        :highlightcolor: -- the color used for "bolded" elements; ; either #RRBBGG or a color name
 
-    A single matrix is defined using javascript array notation, e.g., [a,b,c;d,e,f]
+        A single matrix is defined using javascript array notation, e.g., [a,b,c;d,e,f]
 
-    A "name" can be assigned to a matrix by including a string and a colon after the
-    beginning [, but before the first value, e.g., [M1: a,b,c;d,e,f]. If no name is
-    specified, a default name is assigned.
+        A "name" can be assigned to a matrix by including a string and a colon after the
+        beginning [, but before the first value, e.g., [M1: a,b,c;d,e,f]. If no name is
+        specified, a default name is assigned.
 
-    A background color can be assigned to a matrix by including a color specifier
-    after the matrix's name. The color can be one of the standard HTML color names
-    or a color value (#RRGGBB). To specify a color, you must give the matrix a name.
-    E.g., [M1,lightcyan: a,b,c;d,e,f] or [M1,#DF85E8: a,b,c;d,e,f]
+        A background color can be assigned to a matrix by including a color specifier
+        after the matrix's name. The color can be one of the standard HTML color names
+        or a color value (#RRGGBB). To specify a color, you must give the matrix a name.
+        E.g., [M1,lightcyan: a,b,c;d,e,f] or [M1,#DF85E8: a,b,c;d,e,f]
 
-    Individual elements of a matrix can have no special formatting, be highlighted,
-    be editable, or be both highlighted and editable. To make an element:
-        - highlighted, add an asterisk in front of the value, e.g., *a
-        - editable, put the value inside {}, e.g, {a}
-        - both highlighted and editable, *{a} or {*a}
+        Individual elements of a matrix can have no special formatting, be highlighted,
+        be editable, or be both highlighted and editable. To make an element:
+            - highlighted, add an asterisk in front of the value, e.g., *a
+            - editable, put the value inside {}, e.g, {a}
+            - both highlighted and editable, *{a} or {*a}
 
-    The content of the directive is a matrix equation. E.g.,
-    [M1: 1, 0, 0, 0; 0, 1, 0, 0; 0, 0, -c2, c1; 0, 0, -1, 0]*[M2: x;y;z;1] = [M3: x';y';z';w']
+        The content of the directive is a matrix equation. E.g.,
+        [M1: 1, 0, 0, 0; 0, 1, 0, 0; 0, 0, -c2, c1; 0, 0, -1, 0]*[M2: x;y;z;1] = [M3: x';y';z';w']
     """
 
     required_arguments = 1
     optional_arguments = 0
-    has_content = True    
+    has_content = True
     option_spec = RunestoneDirective.option_spec.copy()
     option_spec.update(
         {
@@ -417,20 +420,21 @@ def purge_matrixeq(app, env, docname):
 # in-line paragraph.
 class InlineMatrixEqNode(nodes.General, nodes.Element, RunestoneNode):
     """
-:inline_matrixeq:`[a,b;c,d]`
+    :inline_matrixeq:`[a,b;c,d]`
 
-    A inline_matrixeq role allows a matrix equation to be defined inside a
-    paragraph. The syntax for the matrix equation is identical to a matrixeq
-    directive. The operators in an in-line matrix equation are not executable.
+        A inline_matrixeq role allows a matrix equation to be defined inside a
+        paragraph. The syntax for the matrix equation is identical to a matrixeq
+        directive. The operators in an in-line matrix equation are not executable.
 
-    In the future it would be nice to figure out how to make the background
-    color user configurable. (For some reason, inheriting the background color
-    from the enclosing parent makes the brackets of the matrices render
-    incorrectly.)
+        In the future it would be nice to figure out how to make the background
+        color user configurable. (For some reason, inheriting the background color
+        from the enclosing parent makes the brackets of the matrices render
+        incorrectly.)
 
-    The background color is hardcoded to a light yellow.
-    The highlight color is hardcoded to red.
+        The background color is hardcoded to a light yellow.
+        The highlight color is hardcoded to red.
     """
+
     pass
 
 
@@ -451,8 +455,7 @@ def inline_matrixeq(
     content=[],
 ):  # A list of strings, the directive _`content` for customization (from the "role"
     # directive). To be interpreted by the role function.
-    """
-    """
+    """ """
     matrix_node = InlineMatrixEqNode()
     matrix_text = re.search(":inline_matrixeq:`(.*)`", rawtext).group(1)
     matrix_node["components"] = {
