@@ -14,6 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 import pdb
+
 __author__ = "bmiller"
 
 from docutils import nodes
@@ -40,7 +41,7 @@ XML_START = """
         <statement>
 
 """
-# TODO: detect old versus new style to include the choices or not
+
 XML_START_END = """
         </statement>
 """
@@ -132,7 +133,8 @@ def visit_mc_xml(self, node):
 
 
 def depart_mc_xml(self, node):
-    self.output.append(XML_START_END)
+    if not node["runestone_options"]["is_new_style"]:
+        self.output.append(XML_START_END)
     res = depart_mc_common(self, node)
     res = res.replace("data-correct", "correct")
     self.output.append(res)
@@ -247,11 +249,11 @@ class MChoice(Assessment):
 
     def run(self):
         """
-            process the multiplechoice directive and generate html for output.
+        process the multiplechoice directive and generate html for output.
 
-            :param self:
-            :return: An MChoiceNode.
-            """
+        :param self:
+        :return: An MChoiceNode.
+        """
 
         super(MChoice, self).run()
 
@@ -260,7 +262,8 @@ class MChoice(Assessment):
         mcNode = MChoiceNode()
         mcNode["runestone_options"] = self.options
         mcNode["source"], mcNode["line"] = self.state_machine.get_source_and_line(
-            self.lineno)
+            self.lineno
+        )
         mcNode["template_start"] = TEMPLATE_START
         mcNode["template_option"] = OPTION
         mcNode["template_end"] = TEMPLATE_END
@@ -307,7 +310,6 @@ class MChoice(Assessment):
                 feedback_bullet_list = answer_list_item[-1]
                 if (
                     not isinstance(feedback_bullet_list, nodes.bullet_list)
-
                     # It should have just one item (the feedback itself).
                     or (len(feedback_bullet_list) != 1)
                 ):
@@ -430,7 +432,8 @@ def visit_answer_list_item(self, node):
     # Format the HTML.
     self.body.append(
         '<li data-component="answer" {is_correct} id="{divid}_opt_{alabel}">'.format(
-            **mc_node["runestone_options"])
+            **mc_node["runestone_options"]
+        )
     )
 
 
@@ -450,8 +453,7 @@ def visit_answer_list_item_xml(self, node):
         self.output.append("<choice>")
     # Format the HTML.
     self.output.append(
-        '<statement id="{divid}_opt_{alabel}">'.format(
-            **mc_node["runestone_options"])
+        '<statement id="{divid}_opt_{alabel}">'.format(**mc_node["runestone_options"])
     )
 
 
@@ -482,7 +484,8 @@ def visit_feedback_list_item(self, node):
     mc_node["runestone_options"]["alabel"] = label
     self.body.append(
         '</li><li data-component="feedback" id="{divid}_opt_{alabel}">\n'.format(
-            **mc_node["runestone_options"])
+            **mc_node["runestone_options"]
+        )
     )
 
 
@@ -494,8 +497,7 @@ def visit_feedback_list_item_xml(self, node):
     mc_node["runestone_options"]["alabel"] = label
     self.output.append("</statement>")
     self.output.append(
-        '<feedback id="{divid}_opt_{alabel}">\n'.format(
-            **mc_node["runestone_options"])
+        '<feedback id="{divid}_opt_{alabel}">\n'.format(**mc_node["runestone_options"])
     )
 
 
@@ -506,6 +508,7 @@ def depart_feedback_list_item(self, node):
 def depart_feedback_list_item_xml(self, node):
     self.output.append("</feedback>")
 
+
 # backwards compatibility
 
 
