@@ -16,25 +16,34 @@
 
 __author__ = "isaiahmayerchak"
 
-from asyncore import write
+# from asyncore import write
 from docutils import nodes
 from docutils.parsers.rst import directives
-from runestone.common.runestonedirective import RunestoneIdDirective, RunestoneIdNode
+from runestone.common.runestonedirective import (
+    RunestoneIdDirective,
+    RunestoneIdNode,
+)
 from runestone.server.componentdb import addQuestionToDB, addHTMLToDB
-from runestone.common.xmlcommon import write_substitute, substitute_departure
+from runestone.common.xmlcommon import (
+    write_substitute,
+    substitute_departure,
+)
 
 
 def setup(app):
     app.add_directive("poll", Poll)
-    app.add_node(PollNode, html=(visit_poll_html, depart_poll_html),
-                 xml=(visit_poll_xml, substitute_departure))
+    app.add_node(
+        PollNode,
+        html=(visit_poll_html, depart_poll_html),
+        xml=(visit_poll_xml, substitute_departure),
+    )
 
     app.add_config_value("poll_div_class", "", "html")
 
 
 TEMPLATE_START = """
 <div class="runestone %(optclass)s">
-<ul data-component="poll" id=%(divid)s %(comment)s class='%(divclass)s' data-results='%(results)s' data-question_label="%(question_label)s" %(optional)s>
+<ul data-component="poll" id="%(divid)s" %(comment)s class='%(divclass)s' data-results='%(results)s' data-question_label="%(question_label)s" %(optional)s>
 %(question)s
 """
 
@@ -66,9 +75,9 @@ def visit_poll_xml(self, node):
 
 
 def depart_poll_html(self, node):
-    """ This is called at the start of processing a poll node.  If poll had recursive nodes
-        etc and did not want to do all of the processing in visit_poll_html any finishing touches could be
-        added here.
+    """This is called at the start of processing a poll node.  If poll had recursive nodes
+    etc and did not want to do all of the processing in visit_poll_html any finishing touches could be
+    added here.
     """
     pass
 
@@ -99,18 +108,18 @@ def visit_poll_common(self, node):
 
 class Poll(RunestoneIdDirective):
     """
-.. poll:: identifier
-    :scale: <X>  Setting the scale creates an "On a scale of 1 to <X>" type of question
-    :allowcomment: Boolean--provides comment box
-    :option_1: Providing Question text for each option creates a "Choose one of these options" type of poll.
-    :option_2: Option 2
-    :option_3: Option 3    ...etc...(Up to 10 options in mode 2)
-    :results: One of all, instructor, superuser - who should see results?
+    .. poll:: identifier
+        :scale: <X>  Setting the scale creates an "On a scale of 1 to <X>" type of question
+        :allowcomment: Boolean--provides comment box
+        :option_1: Providing Question text for each option creates a "Choose one of these options" type of poll.
+        :option_2: Option 2
+        :option_3: Option 3    ...etc...(Up to 10 options in mode 2)
+        :results: One of all, instructor, superuser - who should see results?
 
 
-config values (conf.py):
+    config values (conf.py):
 
-- poll_div_class - custom CSS class of the component's outermost div
+    - poll_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1
@@ -137,16 +146,16 @@ config values (conf.py):
 
     def run(self):
         """
-            process the multiplechoice directive and generate html for output.
-            :param self:
-            :return:
-            .. poll:: id
-                :scale: <X>  Setting the scale creates an "On a scale of 1 to <X>" type of question
-                :allowcomment: Boolean--provides comment box
-                :option_1: Providing Question text for each option creates a "Choose one of these options" type of poll.
-                :option_2: Option 2
-                :option_3: Option 3    ...etc...(Up to 10 options in mode 2)
-                :results: One of all, instructor, superuser - who should see results?
+        process the multiplechoice directive and generate html for output.
+        :param self:
+        :return:
+        .. poll:: id
+            :scale: <X>  Setting the scale creates an "On a scale of 1 to <X>" type of question
+            :allowcomment: Boolean--provides comment box
+            :option_1: Providing Question text for each option creates a "Choose one of these options" type of poll.
+            :option_2: Option 2
+            :option_3: Option 3    ...etc...(Up to 10 options in mode 2)
+            :results: One of all, instructor, superuser - who should see results?
         """
         super(Poll, self).run()
         addQuestionToDB(self)
