@@ -16,7 +16,10 @@
 
 from docutils import nodes
 from docutils.parsers.rst import directives
-from runestone.common.runestonedirective import RunestoneIdDirective, RunestoneIdNode
+from runestone.common.runestonedirective import (
+    RunestoneIdDirective,
+    RunestoneIdNode,
+)
 
 __author__ = "bmiller"
 
@@ -70,11 +73,11 @@ TEMPLATE_END = """
 
 class QuestionDirective(RunestoneIdDirective):
     """
-.. question:: identifier
-   :number: Force a number for this question
+    .. question:: identifier
+       :number: Force a number for this question
 
-   Content  everything here is part of the question
-   Content  It can be a lot...
+       Content  everything here is part of the question
+       Content  It can be a lot...
     """
 
     required_arguments = 1
@@ -92,9 +95,10 @@ class QuestionDirective(RunestoneIdDirective):
 
         question_node = QuestionNode()
         question_node["runestone_options"] = self.options
-        question_node["source"], question_node["line"] = self.state_machine.get_source_and_line(
-            self.lineno
-        )
+        (
+            question_node["source"],
+            question_node["line"],
+        ) = self.state_machine.get_source_and_line(self.lineno)
         self.add_name(question_node)
 
         self.state.nested_parse(self.content, self.content_offset, question_node)
