@@ -15,23 +15,30 @@
 #
 __author__ = "tconzett"
 
-from asyncore import write
+# from asyncore import write
 from docutils import nodes
 from docutils.parsers.rst import directives
 from runestone.common.xmlcommon import substitute_departure
 from runestone.server.componentdb import addQuestionToDB, addHTMLToDB
-from runestone.common.runestonedirective import RunestoneIdDirective, RunestoneIdNode
-from runestone.common.xmlcommon import substitute_departure, write_substitute
+from runestone.common.runestonedirective import (
+    RunestoneIdDirective,
+    RunestoneIdNode,
+)
+from runestone.common.xmlcommon import (
+    substitute_departure,
+    write_substitute,
+)
 
 
 def setup(app):
     app.add_directive("showeval", ShowEval)
 
-    app.add_config_value(
-        "showeval_div_class", "runestone explainer", "html"
+    app.add_config_value("showeval_div_class", "runestone explainer", "html")
+    app.add_node(
+        ShowEvalNode,
+        html=(visit_showeval_html, depart_showeval_html),
+        xml=(visit_showeval_xml, substitute_departure),
     )
-    app.add_node(ShowEvalNode, html=(visit_showeval_html, depart_showeval_html),
-                 xml=(visit_showeval_xml, substitute_departure))
 
 
 # Create visitors, so we can generate HTML after the doctree is resolve (where the question label is determined).
@@ -43,7 +50,9 @@ def visit_showeval_html(self, node):
     html = CODE % node["runestone_options"]
     self.body.append(html)
     addHTMLToDB(
-        node["runestone_options"]["divid"], node["runestone_options"]["basecourse"], html
+        node["runestone_options"]["divid"],
+        node["runestone_options"]["basecourse"],
+        html,
     )
 
 
@@ -74,21 +83,21 @@ CODE = """
 
 class ShowEval(RunestoneIdDirective):
     """
-.. showeval:: unique_id_goes_here
-   :trace_mode: boolean  <- Required option that enables 'Trace Mode'
+    .. showeval:: unique_id_goes_here
+       :trace_mode: boolean  <- Required option that enables 'Trace Mode'
 
-   some code
-   more code
-   ~~~~
-   more {{code}}{{what code becomes in step 1}}
-   ##Optional comment for step 2
-   more {{what code becomes in step 1}}{{what code becomes in step2}}
-   as many steps as you want {{the first double braces}}{{animate into the second}} wherever.
+       some code
+       more code
+       ~~~~
+       more {{code}}{{what code becomes in step 1}}
+       ##Optional comment for step 2
+       more {{what code becomes in step 1}}{{what code becomes in step2}}
+       as many steps as you want {{the first double braces}}{{animate into the second}} wherever.
 
 
-config values (conf.py):
+    config values (conf.py):
 
-- showeval_div_class - custom CSS class of the component's outermost div
+    - showeval_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1
@@ -100,29 +109,29 @@ config values (conf.py):
 
     def run(self):
         """
-        All prerequisite information that should be displayed above the directive,
-        such as variable declaration, are separated from the step strings by "-----".
+            All prerequisite information that should be displayed above the directive,
+            such as variable declaration, are separated from the step strings by "-----".
 
-        The step animations follow the "-----" and are written one per line. Use
-        "{{" and "}}" braces to surround the part of the line that should be replaced,
-        followed by the replacement text also in "{{" and "}}". If you would like to add
-        a comment that will appear in a div beside the animation, denote that at the end
-        of the step where you would like it to appear with "##".
+            The step animations follow the "-----" and are written one per line. Use
+            "{{" and "}}" braces to surround the part of the line that should be replaced,
+            followed by the replacement text also in "{{" and "}}". If you would like to add
+            a comment that will appear in a div beside the animation, denote that at the end
+            of the step where you would like it to appear with "##".
 
-    Example:
+        Example:
 
-    .. showeval:: showEval_0
-       :trace_mode: false
+        .. showeval:: showEval_0
+           :trace_mode: false
 
-       eggs = ['dogs', 'cats', 'moose']
-       ~~~~
+           eggs = ['dogs', 'cats', 'moose']
+           ~~~~
 
-       ''.join({{eggs}}{{['dogs', 'cats', 'moose']}}).upper().join(eggs)
-       ##I want to put a comment here!
-       {{''.join(['dogs', 'cats', 'moose'])}}{{'dogscatsmoose'}}.upper().join(eggs)
-       {{'dogscatsmoose'.upper()}}{{'DOGSCATSMOOSE'}}.join(eggs)
-       'DOGSCATSMOOSE'.join({{eggs}}{{['dogs', 'cats', 'moose']}})
-       {{'DOGSCATSMOOSE'.join(['dogs', 'cats', 'moose'])}}{{'dogsDOGSCATSMOOSEcatsDOGSCATSMOOSEmoose'}}
+           ''.join({{eggs}}{{['dogs', 'cats', 'moose']}}).upper().join(eggs)
+           ##I want to put a comment here!
+           {{''.join(['dogs', 'cats', 'moose'])}}{{'dogscatsmoose'}}.upper().join(eggs)
+           {{'dogscatsmoose'.upper()}}{{'DOGSCATSMOOSE'}}.join(eggs)
+           'DOGSCATSMOOSE'.join({{eggs}}{{['dogs', 'cats', 'moose']}})
+           {{'DOGSCATSMOOSE'.join(['dogs', 'cats', 'moose'])}}{{'dogsDOGSCATSMOOSEcatsDOGSCATSMOOSEmoose'}}
 
         """
 
