@@ -49,6 +49,7 @@ def setup(app):
 class SpreadSheetNode(nodes.General, nodes.Element, RunestoneIdNode):
     pass
 
+
 #
 # The spreadsheet class implements the directive.
 # When the directive is processed the run method is called.
@@ -138,7 +139,8 @@ class SpreadSheet(RunestoneIdDirective):
         ssnode = SpreadSheetNode()
         ssnode["runestone_options"] = self.options
         ssnode["source"], ssnode["line"] = self.state_machine.get_source_and_line(
-            self.lineno)
+            self.lineno
+        )
         self.add_name(ssnode)  # make this divid available as a target for :ref:
 
         return [ssnode]
