@@ -19,7 +19,10 @@ from docutils import nodes
 from docutils.parsers.rst import directives
 
 # We don't use a ``RunestoneIdNode``, because these imply a numbered question, not a GUI element. Likewise, only ``tabbed`` requires a divid; in addition, this divid doesn't need to be globally unique, since it won't be connected with a question in the database. Therefore, just use a RunestoneDirectory for these.
-from runestone.common.runestonedirective import RunestoneDirective, RunestoneNode
+from runestone.common.runestonedirective import (
+    RunestoneDirective,
+    RunestoneNode,
+)
 
 
 def setup(app):
@@ -78,6 +81,7 @@ def depart_tab_html(self, node):
 
 class TabbedStuffNode(nodes.General, nodes.Element, RunestoneNode):
     """A TabbedStuffNode contains one or more TabNodes"""
+
     pass
 
 
@@ -114,16 +118,16 @@ def depart_tabbedstuff_html(self, node):
 
 class TabDirective(RunestoneDirective):
     """
-.. tab:: identifier
-   :active: Optional flag that specifies this tab to be opened when page is loaded (default is first tab)--overridden by :inactive: flag on tabbedStuff
+    .. tab:: identifier
+       :active: Optional flag that specifies this tab to be opened when page is loaded (default is first tab)--overridden by :inactive: flag on tabbedStuff
 
-   Content
-   ...
+       Content
+       ...
 
 
-config values (conf.py):
+    config values (conf.py):
 
-- tabbed_div_class - custom CSS class of the component's outermost div
+    - tabbed_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1  # the name of the tab
@@ -131,23 +135,21 @@ config values (conf.py):
     final_argument_whitespace = True
     has_content = True
     option_spec = RunestoneDirective.option_spec.copy()
-    option_spec.update(
-        {"active": directives.flag}
-    )
+    option_spec.update({"active": directives.flag})
 
     node_class = TabNode
 
     def run(self):
         """
-            process the tab directive and generate html for output.
-            :param self:
-            :return:
-            .. tab:: identifier
-            :active: Optional flag that specifies this tab to be opened when page is loaded (default is first tab)--overridden by :inactive: flag on tabbedStuff
+        process the tab directive and generate html for output.
+        :param self:
+        :return:
+        .. tab:: identifier
+        :active: Optional flag that specifies this tab to be opened when page is loaded (default is first tab)--overridden by :inactive: flag on tabbedStuff
 
-            Content
-            ...
-            """
+        Content
+        ...
+        """
         # Raise an error if the directive does not have contents.
         self.assert_has_content()
 
@@ -164,17 +166,17 @@ config values (conf.py):
 
 class TabbedStuffDirective(RunestoneDirective):
     """
-.. tabbed:: identifier
-   :inactive: Optional flag that calls for no tabs to be open on page load
+    .. tabbed:: identifier
+       :inactive: Optional flag that calls for no tabs to be open on page load
 
-   Content (put tabs here)
-   ...
+       Content (put tabs here)
+       ...
 
 
 
-config values (conf.py):
+    config values (conf.py):
 
-- tabbed_div_class - custom CSS class of the component's outermost div
+    - tabbed_div_class - custom CSS class of the component's outermost div
     """
 
     required_arguments = 1  # the div to put the tabbed exhibit in
@@ -182,21 +184,19 @@ config values (conf.py):
     final_argument_whitespace = True
     has_content = True
     option_spec = RunestoneDirective.option_spec.copy()
-    option_spec.update(
-        {"inactive": directives.flag}
-    )
+    option_spec.update({"inactive": directives.flag})
 
     def run(self):
         """
-            process the tabbedStuff directive and generate html for output.
-            :param self:
-            :return:
-            .. tabbed:: identifier
-            :inactive: Optional flag that calls for no tabs to be open on page load
+        process the tabbedStuff directive and generate html for output.
+        :param self:
+        :return:
+        .. tabbed:: identifier
+        :inactive: Optional flag that calls for no tabs to be open on page load
 
-            Content (put tabs here)
-            ...
-            """
+        Content (put tabs here)
+        ...
+        """
 
         # Raise an error if the directive does not have contents.
         self.assert_has_content()
@@ -212,9 +212,10 @@ config values (conf.py):
         tabbedstuff_node["tabbed_stuff_options"] = self.options
         tabbedstuff_node["divid"] = self.options["divid"]
 
-        tabbedstuff_node["source"], tabbedstuff_node["line"] = self.state_machine.get_source_and_line(
-            self.lineno
-        )
+        (
+            tabbedstuff_node["source"],
+            tabbedstuff_node["line"],
+        ) = self.state_machine.get_source_and_line(self.lineno)
 
         # Parse the directive contents (should be 1 or more tab directives)
         self.state.nested_parse(self.content, self.content_offset, tabbedstuff_node)
