@@ -36,7 +36,10 @@ __author__ = "isaiahmayerchak"
 # -------
 from docutils import nodes
 from docutils.parsers.rst import directives
-from runestone.common.runestonedirective import RunestoneIdDirective, RunestoneIdNode
+from runestone.common.runestonedirective import (
+    RunestoneIdDirective,
+    RunestoneIdNode,
+)
 from runestone.server.componentdb import addAssignmentToDB
 
 # Timed Assessment Implementation
@@ -167,9 +170,10 @@ class TimedDirective(RunestoneIdDirective):
 
         timed_node = TimedNode()
         timed_node["runestone_options"] = self.options
-        timed_node["source"], timed_node["line"] = self.state_machine.get_source_and_line(
-            self.lineno
-        )
+        (
+            timed_node["source"],
+            timed_node["line"],
+        ) = self.state_machine.get_source_and_line(self.lineno)
         # Use the environment so that any parsed directives will know they
         # are inside a timed exam.
         env = self.state.document.settings.env
