@@ -30,8 +30,11 @@ def setup(app):
     app.add_directive("video", Video)
     app.add_directive("youtube", Youtube)
     app.add_directive("vimeo", Vimeo)
-    app.add_node(VideoNode, html=(visit_video_html, depart_video_html),
-                 xml=(visit_video_xml, depart_video_xml))
+    app.add_node(
+        VideoNode,
+        html=(visit_video_html, depart_video_html),
+        xml=(visit_video_xml, depart_video_xml),
+    )
 
 
 CODE = """\
@@ -98,7 +101,9 @@ def visit_video_html(self, node):
     html = node["template"] % node["runestone_options"]
     self.body.append(html)
     addHTMLToDB(
-        node["runestone_options"]["divid"], node["runestone_options"]["basecourse"], html
+        node["runestone_options"]["divid"],
+        node["runestone_options"]["basecourse"],
+        html,
     )
 
 
@@ -117,15 +122,15 @@ def depart_video_html(self, node):
 
 class Video(RunestoneIdDirective):
     """
-.. video:: id
-   :controls:  Show the controls or not
-   :loop: loop the video
-   :thumb: url to thumbnail image
-   :preload: set the video to preload in the bg
+    .. video:: id
+       :controls:  Show the controls or not
+       :loop: loop the video
+       :thumb: url to thumbnail image
+       :preload: set the video to preload in the bg
 
-   url to video format 1
-   url to video format 2
-   ...
+       url to video format 1
+       url to video format 2
+       ...
     """
 
     required_arguments = 1
@@ -259,15 +264,15 @@ class IframeVideo(RunestoneIdDirective):
 
 class Youtube(IframeVideo):
     """
-.. youtube:: YouTubeID
-   :divid: the runestone id for this video
-   :height: 315
-   :width: 560
-   :align: left
-   :http: http
-   :start: None
-   :end: None
-   """
+    .. youtube:: YouTubeID
+       :divid: the runestone id for this video
+       :height: 315
+       :width: 560
+       :align: left
+       :http: http
+       :start: None
+       :end: None
+    """
 
     html = """
     <div class="runestone %(optclass)s" style="margin-left: auto; margin-right:auto">
@@ -298,11 +303,11 @@ class Youtube(IframeVideo):
 
 class Vimeo(IframeVideo):
     """
-.. vimeo:: vimeoID
-   :height: 315
-   :width: 560
-   :align: left
-   :http: http
+    .. vimeo:: vimeoID
+       :height: 315
+       :width: 560
+       :align: left
+       :http: http
     """
 
     html = '<iframe src="%(http)s://player.vimeo.com/video/%(video_id)s" \
